@@ -15,7 +15,7 @@ from cryptography.hazmat.primitives import hashes
 from cryptography.hazmat.primitives.asymmetric import ec
 from pydantic import Base64Bytes, BaseModel, TypeAdapter, ValidationError
 from sigstore.dsse import DigestSet, StatementBuilder, Subject
-from sigstore.models import Bundle
+from sigstore.models import Bundle, ClientTrustConfig
 from sigstore.oidc import IdentityToken
 from sigstore.sign import SigningContext
 from sigstore.verify import Verifier, policy
@@ -23,7 +23,7 @@ from sigstore.verify import Verifier, policy
 import pypi_attestations._impl as impl
 
 ONLINE_TESTS = (
-    "CI" in os.environ or "TEST_INTERACTIVE" in os.environ
+    "CI" in os.environ or "EXTREMELY_DANGEROUS_PUBLIC_OIDC_BEACON" in os.environ
 ) and "TEST_OFFLINE" not in os.environ
 
 online = pytest.mark.skipif(not ONLINE_TESTS, reason="online tests not enabled")
@@ -69,7 +69,10 @@ class TestDistribution:
 class TestAttestation:
     @online
     def test_roundtrip(self, id_token: IdentityToken) -> None:
-        sign_ctx = SigningContext.staging()
+        trust_config = ClientTrustConfig.staging()
+        # Make sure we use rekor v1 until attestations are compatible with v2
+        trust_config.force_tlog_version = 1
+        sign_ctx = SigningContext.from_trust_config(trust_config)
 
         with sign_ctx.signer(id_token) as signer:
             attestation = impl.Attestation.sign(signer, dist)
@@ -103,7 +106,11 @@ class TestAttestation:
 
         monkeypatch.setattr(IdentityToken, "in_validity_period", in_validity_period)
 
-        sign_ctx = SigningContext.staging()
+        trust_config = ClientTrustConfig.staging()
+        # Make sure we use rekor v1 until attestations are compatible with v2
+        trust_config.force_tlog_version = 1
+        sign_ctx = SigningContext.from_trust_config(trust_config)
+
         with sign_ctx.signer(id_token, cache=False) as signer:
             with pytest.raises(impl.AttestationError):
                 impl.Attestation.sign(signer, dist)
@@ -115,12 +122,15 @@ class TestAttestation:
         def get_bundle(*_: Any) -> Bundle:
             # Duplicate the signature to trigger a Conversion error
             bundle = Bundle.from_json(gh_signed_dist_bundle_path.read_bytes())
-            bundle._inner.dsse_envelope.signatures.append(bundle._inner.dsse_envelope.signatures[0])
+            bundle._inner.dsse_envelope.signatures.append(bundle._inner.dsse_envelope.signatures[0])  # type: ignore[union-attr]
             return bundle
 
         monkeypatch.setattr(sigstore.sign.Signer, "sign_dsse", get_bundle)
 
-        sign_ctx = SigningContext.staging()
+        trust_config = ClientTrustConfig.staging()
+        # Make sure we use rekor v1 until attestations are compatible with v2
+        trust_config.force_tlog_version = 1
+        sign_ctx = SigningContext.from_trust_config(trust_config)
 
         with pytest.raises(impl.AttestationError):
             with sign_ctx.signer(id_token) as signer:
@@ -485,9 +495,17 @@ class TestAttestation:
         assert subject_name != dist.name
 
 
+def test_from_bundle_not_dsse() -> None:
+    bundle = Bundle.from_json(dist_bundle_path.read_bytes())
+    bundle._inner.dsse_envelope = None
+
+    with pytest.raises(impl.ConversionError, match="bundle does not contain a DSSE envelope"):
+        impl.Attestation.from_bundle(bundle)
+
+
 def test_from_bundle_missing_signatures() -> None:
     bundle = Bundle.from_json(dist_bundle_path.read_bytes())
-    bundle._inner.dsse_envelope.signatures = []  # noqa: SLF001
+    bundle._inner.dsse_envelope.signatures = []  # type: ignore # noqa: SLF001
 
     with pytest.raises(impl.ConversionError, match="expected exactly one signature, got 0"):
         impl.Attestation.from_bundle(bundle)
@@ -724,8 +742,8 @@ class TestGitHubPublisher:
             .issuer_name(orig_cert.issuer)
             .public_key(orig_cert.public_key())
             .serial_number(orig_cert.serial_number)
-            .not_valid_before(orig_cert.not_valid_before)
-            .not_valid_after(orig_cert.not_valid_after)
+            .not_valid_before(orig_cert.not_valid_before_utc)
+            .not_valid_after(orig_cert.not_valid_after_utc)
         )
 
         for ext in orig_cert.extensions:
